@@ -99,6 +99,8 @@ ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt
 
 =item * ߋ̃f[^AXNvgAmEnEƌ݊ۂĂ
 
+=item * Sjis.pm  Esjis.pm ŋ@\(̃W[ȂƂ܂)
+
 =item * UTF8 tOȂł(perlunitut  perluniadvice ̑Ή͕sv)
 
 =item * (JPerlێ炷邽߂) C vO~OsȂł
@@ -455,8 +457,8 @@ oO񍐁Apb`}܂B
 
 =item * chdir
 
-    MSWin32  perl5.006, perl5.008, perl5.010 ɂĕR[h(0x5C)ŏI
-    pXƂł܂B
+    MSWin32  perl5.006, perl5.008, perl5.010, perl5.012 ɂĕR[h(0x5C)
+    ŏIpXƂł܂B
 
     QlN
     Bug #81839
@@ -752,7 +754,7 @@ uShift_JISvɏ邱Ƃ𐄏ĂB
 11438ׂĂ邱ƂڎwĂ܂B̂߂ɃASY2g
 Ă܂B
 
-  * ASY 1
+* ASY 1
 
     INebg̕т當oƂA1INebgR[h2INebgR[h
     ̋ʂ͑1INebgR[ĥ݂ōs܂B2INebg͍l܂B
@@ -847,13 +849,13 @@ uShift_JISvɏ邱Ƃ𐄏ĂB
   +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+               +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 
 
-    *s* 1INebgR[h
-
 ̍ŏIINebg2INebgR[h̑1INebgƓꍇ
 
 słĂꂽAIɍ폜邱Ƃ͂܂B
 Ⴆ΁AEsjis::chop ͂̃INebgԂ܂B
 
+    *s* 1INebgR[h
+
    0 1 2 3 4 5 6 7 8 9 A B C D E F 
   +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
  0| | | | | | | | | | | | | | | | |
@@ -919,7 +921,7 @@ http://home.m05.itscom.net/numa/cde/sjis-euc/sjis.html
  Hewlett-Packard HP-15          0x00-0x7F, 0xA1-0xDF, (0x80-0xA0, 0xE0-0xFE)(0x21-0x7E, 0x80-0xFF)
 
 
-  * ASY 2
+* ASY 2
 
     ASY 1 ɂւ炸Atr/// ɂ蕶͈̔͂w肳ꂽꍇ͈ȉ̕
     ݂̂LƂȂ܂B
@@ -1233,6 +1235,13 @@ vO~O񋟂܂B
  ISBN 978-4-87311-359-3
  http://www.oreilly.co.jp/books/9784873113593/
 
+ K\NbNubN
+ Jan Goyvaerts, Steven Levithan ,  O 
+ 2010N0414 \
+ 552y[W
+ ISBN978-4-87311-450-7
+ http://www.oreilly.co.jp/books/9784873114507/
+
  PerlvO~O
  Larry Wall, Randal L.Schwartz, ߓ Ð 
  1993N2s
